==> redquicklib-1.6.0.tgz: package/lib/components/reactnativesignout.js <==
'use strict';

import React, { Component } from 'react';
import {
    AppRegistry,
    StyleSheet,
    Text,
    WebView,
    View, AsyncStorage
} from 'react-native';
import locationservice from '../util/locationservice';
import * as Common from '../screens/customer/common';
// Change these to reflect
var signoutPromise = Promise.resolve();
export default class ReactNativeSignout extends Component {
    constructor(props) {
        super(props);
        this.state = {
            loggedIn: false,
            loadedCookie: false
        };
    }

    componentWillMount() {
        var me = this;
        //Common.runAfter(me, () => {
        me._loadInitialState();
        //});

    }
    _loadInitialState = async () => {
        this.setState({
            loggedIn: false,
            loadedCookie: true,
            signoutcomplete: false
        });
    }
    getParmFromHash(navState, parm) {
        var accessToken = null;
        var accesst = '#access_token=';
        var accessIndex = navState.url.indexOf(accesst);
        if (accessIndex !== -1) {
            var accessIndexEnd = navState.url.indexOf('&');
            accessIndex = accessIndex !== -1 ? accessIndex : navState.url.length;
            accessToken = navState.url.substring(accessIndex + accesst.length, accessIndexEnd);
        }
        UIA.log(`accessToken : ${accessToken}`);
        return accessToken;
    }
    onNavigationStateChange(navState) {
        var me = this;
        // If we get redirected back to the HOME_URL we know that we are logged in. If your backend does something different than this
        // change this line.
        var {
            signoutUrl,
            signoutUrlComplete,
            signoutHeroUrl,
            signoutHeroUrlComplete
        } = this.props;
        console.log(navState);
        if (me.state.signoutcomplete) {
            return;
        }
        var removebearer = () => {
            locationservice.stop();
            me.setState({ signOutHero: true, signoutcomplete: true });
            return AsyncStorage.setItem('bearer-token', '');
        }
        if (navState.url.indexOf(signoutUrlComplete) !== -1
            || navState.url.indexOf(signoutHeroUrlComplete) !== -1) {
            signoutPromise = signoutPromise.then(() => {
                return removebearer().then(() => {
                    if (me.props.onSignOutComplete) {
                        me.props.onSignOutComplete();
                    }
                });
            });
        }

        // var accessToken = this.getParmFromHash(navState, 'access_token');
        // if (accessToken) {
        //     this.setState({
        //         loggedIn: true,
        //         accessToken
        //     });
        //     if (this.props.onAuthentification) {
        //         this.props.onAuthentification(accessToken);
        //     }
        // }
        // this.setState({ signoutUrl: navState.url })
    }
    getLoginView() {
        var { loginView } = this.props;
        if (loginView) {
            UIA.log('returning loginview')
            return loginView
        }
        return (
            <View>
                <Text>
                    Logged in.
                </Text>
            </View>
        )
    }
    getInitialView() {
        var { initialview } = this.props;
        return initialview || null;
    }
    render() {
        if (this.state.busy) {
            return Common.HeroBanner();
        }
        var { signoutUrl, signoutHeroUrl } = this.props;
        var loginview = this.getLoginView();
        var initialview = this.getInitialView();
        // If we have completed loading the cookie choose to show Login WebView or the LoggedIn component, else just show an empty View.
        if (this.state.loadedCookie) {
            if (this.state.signOutHero) {
                return (
                    <View style={styles.container}>
                        <WebView
                            ref={'webview'}
                            automaticallyAdjustContentInsets={false}
                            style={styles.webView}
                            source={{ uri: signoutHeroUrl }}
                            javaScriptEnabled={true}
                            onNavigationStateChange={this.onNavigationStateChange.bind(this)}
                            startInLoadingState={true}
                            scalesPageToFit={true}
                        />
                    </View>
                );
            }
            else {
                return (
                    <View style={styles.container}>
                        <WebView
                            ref={'webview'}
                            automaticallyAdjustContentInsets={false}
                            style={styles.webView}
                            source={{ uri: signoutUrl }}
                            javaScriptEnabled={true}
                            onNavigationStateChange={this.onNavigationStateChange.bind(this)}
                            startInLoadingState={true}
                            scalesPageToFit={true}
                        />
                    </View>
                );
            }
        }
        else {
            return (
                <View>
                    {initialview}
                </View>
            );
        }
    }
}

const styles = StyleSheet.create({
    welcome: {
        fontSize: 20,
        textAlign: 'center',
        margin: 10,
        height: 300,
        width: 200
    },
    webView: {},
    instructions: {
        textAlign: 'center',
        color: '#333333',
        marginBottom: 5,
    },
    container: {
        flex: 1,
        backgroundColor: '#F5FCFF',
        alignSelf: 'stretch',
        alignItems: 'stretch'
    }
});

==> redquicklib-1.289.0.tgz: package/lib/components/reactnativesignout.js <==
'use strict';

import React, { Component } from 'react';
import {
    AppRegistry,
    StyleSheet,
    Text,
    WebView,
    View, AsyncStorage
} from 'react-native';
import locationservice from '../locationservice';
import * as Common from '../common';
// Change these to reflect
var signoutPromise = Promise.resolve();
export default class ReactNativeSignout extends Component {
    constructor(props) {
        super(props);
        this.state = {
            loggedIn: false,
            loadedCookie: false
        };
    }

    componentWillMount() {
        var me = this;
        //Common.runAfter(me, () => {
        me._loadInitialState();
        //});

    }
    _loadInitialState = async () => {
        this.setState({
            loggedIn: false,
            loadedCookie: true,
            signoutcomplete: false
        });
    }
    getParmFromHash(navState, parm) {
        var accessToken = null;
        var accesst = '#access_token=';
        var accessIndex = navState.url.indexOf(accesst);
        if (accessIndex !== -1) {
            var accessIndexEnd = navState.url.indexOf('&');
            accessIndex = accessIndex !== -1 ? accessIndex : navState.url.length;
            accessToken = navState.url.substring(accessIndex + accesst.length, accessIndexEnd);
        }
        UIA.log(`accessToken : ${accessToken}`);
        return accessToken;
    }
    onNavigationStateChange(navState) {
        var me = this;
        // If we get redirected back to the HOME_URL we know that we are logged in. If your backend does something different than this
        // change this line.
        var {
            signoutUrl,
            signoutUrlComplete,
            signoutHeroUrl,
            signoutHeroUrlComplete
        } = this.props;
        console.log(navState);
        if (me.state.signoutcomplete) {
            return;
        }
        var removebearer = () => {
            locationservice.stop();
            me.setState({ signOutHero: true, signoutcomplete: true });
            return AsyncStorage.setItem('bearer-token', '');
        }
        if (navState.url.indexOf(signoutUrlComplete) !== -1
            || navState.url.indexOf(signoutHeroUrlComplete) !== -1) {
            signoutPromise = signoutPromise.then(() => {
                return removebearer().then(() => {
                    if (me.props.onSignOutComplete) {
                        me.props.onSignOutComplete();
                    }
                });
            });
        }

        // var accessToken = this.getParmFromHash(navState, 'access_token');
        // if (accessToken) {
        //     this.setState({
        //         loggedIn: true,
        //         accessToken
        //     });
        //     if (this.props.onAuthentification) {
        //         this.props.onAuthentification(accessToken);
        //     }
        // }
        // this.setState({ signoutUrl: navState.url })
    }
    getLoginView() {
        var { loginView } = this.props;
        if (loginView) {
            UIA.log('returning loginview')
            return loginView
        }
        return (
            <View>
                <Text>
                    Logged in.
                </Text>
            </View>
        )
    }
    getInitialView() {
        var { initialview } = this.props;
        return initialview || null;
    }
    render() {
        if (this.state.busy) {
            return Common.HeroBanner();
        }
        var { signoutUrl, signoutHeroUrl } = this.props;
        var loginview = this.getLoginView();
        var initialview = this.getInitialView();
        // If we have completed loading the cookie choose to show Login WebView or the LoggedIn component, else just show an empty View.
        if (this.state.loadedCookie) {
            if (this.state.signOutHero) {
                return (
                    <View style={styles.container}>
                        <WebView
                            ref={'webview'}
                            automaticallyAdjustContentInsets={false}
                            style={styles.webView}
                            source={{ uri: signoutHeroUrl }}
                            javaScriptEnabled={true}
                            onNavigationStateChange={this.onNavigationStateChange.bind(this)}
                            startInLoadingState={true}
                            scalesPageToFit={true}
                        />
                    </View>
                );
            }
            else {
                return (
                    <View style={styles.container}>
                        <WebView
                            ref={'webview'}
                            automaticallyAdjustContentInsets={false}
                            style={styles.webView}
                            source={{ uri: signoutUrl }}
                            javaScriptEnabled={true}
                            onNavigationStateChange={this.onNavigationStateChange.bind(this)}
                            startInLoadingState={true}
                            scalesPageToFit={true}
                        />
                    </View>
                );
            }
        }
        else {
            return (
                <View>
                    {initialview}
                </View>
            );
        }
    }
}

const styles = StyleSheet.create({
    welcome: {
        fontSize: 20,
        textAlign: 'center',
        margin: 10,
        height: 300,
        width: 200
    },
    webView: {},
    instructions: {
        textAlign: 'center',
        color: '#333333',
        marginBottom: 5,
    },
    container: {
        flex: 1,
        backgroundColor: '#F5FCFF',
        alignSelf: 'stretch',
        alignItems: 'stretch'
    }
});
